/****************************************************************************
*
*                   SciTech Multi-platform Graphics Library
*
*  ========================================================================
*
*   Copyright (C) 1991-2002 SciTech Software, Inc. All rights reserved.
*
*   This file may be distributed and/or modified under the terms of the
*   GNU Lesser General Public License version 2.1 as published by the Free
*   Software Foundation and appearing in the file LICENSE.LGPL included
*   in the packaging of this file.
*
*   Licensees holding a valid Commercial License for this product from
*   SciTech Software, Inc. may use this file in accordance with the
*   Commercial License Agreement provided with the Software.
*
*   This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING
*   THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
*   PURPOSE.
*
*   See http://www.scitechsoft.com/license/ for information about
*   the licensing options available and how to purchase a Commercial
*   License Agreement.
*
*   Contact license@scitechsoft.com if any conditions of this licensing
*   are not clear to you, or you have questions about licensing options.
*
*  ========================================================================
*
* Language:     ANSI C
* Environment:  Any
*
* Description:  Polyline drawing routines
*
****************************************************************************/

#include "mgl.h"                /* Private declarations                 */

/*------------------------- Implementation --------------------------------*/

/****************************************************************************
DESCRIPTION:
Draws a set of pixels.

HEADER:
mgraph.h

PARAMETERS:
count   - Number of vertices in polyline
vArray  - Array of coordinates to draw the pixels at

REMARKS:
This function draws a set of pixels in the current color at the locations passed in the
vArray parameter.

SEE ALSO:
MGL_polyLine, MGL_polyMarker
****************************************************************************/
void MGLAPI MGL_polyPoint(
    int count,
    point_t *vArray)
{
    MGL_beginPixel();
    while (count--) {
        MGL_pixel(*vArray);
        vArray++;
        }
    MGL_endPixel();
}

/****************************************************************************
DESCRIPTION:
Draws a set of connected lines.

HEADER:
mgraph.h

PARAMETERS:
count   - Number of vertices in polyline
vArray  - Array of vertices in the polyline

REMARKS:
This function draws a set of connected line (a polyline). The coordinates of the
polyline are specified by vArray, and the lines are drawn in the current drawing
attributes.

Note that the polyline is not closed by default, so if you wish to draw the outline of
a polygon, you will need to add the starting point to the end of the vertex array.

SEE ALSO:
MGL_polyMarker, MGL_polyPoint
****************************************************************************/
void MGLAPI MGL_polyLine(
    int count,
    point_t *vArray)
{
    int     i;
    point_t *p1,*p2;

    p1 = vArray;
    p2 = vArray+1;
    i = count;
    while (--i) {
        MGL_lineExt(*p1,*p2,i == 1);
        p1 = p2++;
        }
}
